@@ -125,7 +125,7 @@ class Dynatrace:
         :return: A list of monitored entities along with their properties.
         """
         params = {"pageSize": page_size, "entitySelector": entity_selector, "from": time_from, "to": time_to, "fields": fields}
-        return PaginatedList(Entity, self.__http_client, "/api/v2/entities", params, list_item="entities", threads=20)
+        return PaginatedList(Entity, self.__http_client, "/api/v2/entities", params, list_item="entities")
 
     def get_entity_types(self, page_size=50) -> PaginatedList[EntityType]:
         """
